Learn R Programming

RGremlinsConjoint (version 0.9.1)

convert_to_bayesm: Convert 'RGremlinsConjoint' formatted Data to 'bayesm' format

Description

Converts a data file and a coded design file from the format expected by the package to a format appropriate for estimation in 'bayesm' rhierMnlRwMixture

Usage

convert_to_bayesm(data, design)

Value

lgtdata The list data structure for use with 'bayesm'

Arguments

data

The data.frame or matrix that contains the respondents answers

design

The data.frame or matrix that contains the coded design

See Also

code_sawtooth_design

Examples

Run this code
if (FALSE) {
 data <- read.csv("data.csv")
 design <- read.csv("design.csv")
 design <- code_sawtooth_design(design)
 convert_to_bayesm(data, design)
}

Run the code above in your browser using DataLab