convert_to_bayesm: Convert 'RGremlinsConjoint' formatted Data to 'bayesm' format
Description
Converts a data file and a coded design file from the format expected by the
package to a format appropriate for estimation in 'bayesm'
rhierMnlRwMixture
Usage
convert_to_bayesm(data, design)
Value
lgtdata The list data structure for use with 'bayesm'
Arguments
data
The data.frame or matrix that contains the respondents answers
design
The data.frame or matrix that contains the coded design